==> llm-docs-0.1.2.tgz: package/docs/getting-started/installation.md <==
---
id: getting-started-installation
---
# Installation Guide

<!-- title: Installation Guide -->
<!-- description: Detailed installation instructions for the Bluefly Platform -->
<!-- lastUpdated: 2024-03-19 -->

This guide provides detailed instructions for installing and configuring the Bluefly Platform components.

## System Requirements

### Hardware Requirements
- CPU: 4+ cores
- RAM: 8GB minimum (16GB recommended)
- Storage: 20GB minimum free space
- Network: Stable internet connection

### Software Requirements
- Operating System:
  - macOS 10.15+
  - Ubuntu 20.04+ / Debian 11+
  - Windows 10/11 with WSL2
- Node.js 18.x or later
- Git 2.30+
- Docker 20.10+ and Docker Compose
- Python 3.9+ (for AI components)

## Installation Steps

### 1. Install Node.js

Using Volta (recommended):
```bash
# Install Volta
curl https://get.volta.sh | bash

# Install Node.js
volta install node@18

# Verify installation
node --version
npm --version
```

Using nvm:
```bash
# Install nvm
curl -o- https://raw.githubusercontent.com/nvm-sh/nvm/v0.39.0/install.sh | bash

# Install Node.js
nvm install 18
nvm use 18

# Verify installation
node --version
npm --version
```

### 2. Install BFCLI

```bash
# Install BFCLI globally
npm install -g @bluefly/cli

# Verify installation
bfcli --version
```

### 3. Install Docker

#### macOS
```bash
# Using Homebrew
brew install --cask docker

# Start Docker Desktop
open -a Docker
```

#### Ubuntu/Debian
```bash
# Add Docker repository
curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo gpg --dearmor -o /usr/share/keyrings/docker-archive-keyring.gpg
echo "deb [arch=$(dpkg --print-architecture) signed-by=/usr/share/keyrings/docker-archive-keyring.gpg] https://download.docker.com/linux/ubuntu $(lsb_release -cs) stable" | sudo tee /etc/apt/sources.list.d/docker.list > /dev/null

# Install Docker
sudo apt-get update
sudo apt-get install docker-ce docker-ce-cli containerd.io docker-compose-plugin

# Add user to docker group
sudo usermod -aG docker $USER

# Start Docker service
sudo systemctl start docker
sudo systemctl enable docker
```

### 4. Configure Environment

1. Create a `.env` file in your project directory:
```bash
# API Configuration
BF_API_URL=https://api.bluefly.io
BF_API_KEY=your_api_key_here

# Database Configuration
BF_DB_HOST=localhost
BF_DB_PORT=5432
BF_DB_NAME=bluefly
BF_DB_USER=bluefly
BF_DB_PASSWORD=your_password_here

# AI Model Configuration
BF_MODEL_PATH=/path/to/models
BF_MODEL_API_KEY=your_model_api_key_here

# Drupal Configuration
DRUPAL_ROOT=/path/to/drupal
DRUPAL_SITE=default
```

2. Set up Git configuration:
```bash
git config --global user.name "Your Name"
git config --global user.email "your.email@example.com"
```

### 5. Install Drupal (Optional)

If you're using Drupal integration:

1. Install Composer:
```bash
curl -sS https://getcomposer.org/installer | php
sudo mv composer.phar /usr/local/bin/composer
```

2. Create a new Drupal project:
```bash
composer create-project drupal/recommended-project my-drupal-site
cd my-drupal-site
```

3. Install required modules:
```bash
composer require drupal/mcp drupal/mcp_client drupal/eca
```

## Verification

After installation, verify your setup:

1. Check BFCLI:
```bash
bfcli status
```

2. Verify Docker:
```bash
docker ps
docker-compose version
```

3. Test API connection:
```bash
bfcli api test
```

4. Check Drupal installation (if applicable):
```bash
bfcli drupal status
```

## Troubleshooting

Common issues and solutions:

1. **Node.js Version Mismatch**
   ```bash
   # Check current version
   node --version
   
   # Switch versions if needed
   volta install node@18
   # or
   nvm use 18
   ```

2. **Docker Permission Issues**
   ```bash
   # Add user to docker group
   sudo usermod -aG docker $USER
   
   # Log out and back in, or run:
   newgrp docker
   ```

3. **API Connection Issues**
   - Verify API key in `.env`
   - Check network connectivity
   - Ensure API service is running

4. **Drupal Installation Issues**
   - Verify Composer installation
   - Check PHP version (7.4+ required)
   - Ensure database credentials are correct

## Next Steps

- [Quick Start Guide](./quickstart): Begin using the platform
- [Configuration Guide](../reference/configuration): Advanced configuration options
- [Development Setup](../development/setup): Set up your development environment

## Support

If you encounter issues:
1. Check the [troubleshooting guide](../troubleshooting/README)
2. Search [GitLab Issues](https://gitlab.com/blueflyio/internal-projects/llm/-/issues)
3. Contact support with:
   - Installation logs
   - System information
   - Error messages
   - Steps to reproduce

==> llm-docs-0.1.4.tgz: package/docs/getting-started/installation.md <==
---
id: getting-started-installation
---
# Installation Guide

<!-- title: Installation Guide -->
<!-- description: Detailed installation instructions for the LLM Platform Platform -->
<!-- lastUpdated: 2024-03-19 -->

This guide provides detailed instructions for installing and configuring the LLM Platform Platform components.

## System Requirements

### Hardware Requirements
- CPU: 4+ cores
- RAM: 8GB minimum (16GB recommended)
- Storage: 20GB minimum free space
- Network: Stable internet connection

### Software Requirements
- Operating System:
  - macOS 10.15+
  - Ubuntu 20.04+ / Debian 11+
  - Windows 10/11 with WSL2
- Node.js 18.x or later
- Git 2.30+
- Docker 20.10+ and Docker Compose
- Python 3.9+ (for AI components)

## Installation Steps

### 1. Install Node.js

Using Volta (recommended):
```bash
# Install Volta
curl https://get.volta.sh | bash

# Install Node.js
volta install node@18

# Verify installation
node --version
npm --version
```

Using nvm:
```bash
# Install nvm
curl -o- https://raw.githubusercontent.com/nvm-sh/nvm/v0.39.0/install.sh | bash

# Install Node.js
nvm install 18
nvm use 18

# Verify installation
node --version
npm --version
```

### 2. Install llmcli

```bash
# Install llmcli globally
npm install -g @bluefly/cli

# Verify installation
llmcli --version
```

### 3. Install Docker

#### macOS
```bash
# Using Homebrew
brew install --cask docker

# Start Docker Desktop
open -a Docker
```

#### Ubuntu/Debian
```bash
# Add Docker repository
curl -fsSL https://download.docker.com/linux/ubuntu/gpg | sudo gpg --dearmor -o /usr/share/keyrings/docker-archive-keyring.gpg
echo "deb [arch=$(dpkg --print-architecture) signed-by=/usr/share/keyrings/docker-archive-keyring.gpg] https://download.docker.com/linux/ubuntu $(lsb_release -cs) stable" | sudo tee /etc/apt/sources.list.d/docker.list > /dev/null

# Install Docker
sudo apt-get update
sudo apt-get install docker-ce docker-ce-cli containerd.io docker-compose-plugin

# Add user to docker group
sudo usermod -aG docker $USER

# Start Docker service
sudo systemctl start docker
sudo systemctl enable docker
```

### 4. Configure Environment

1. Create a `.env` file in your project directory:
```bash
# API Configuration
BF_API_URL=https://api.bluefly.io
BF_API_KEY=your_api_key_here

# Database Configuration
BF_DB_HOST=localhost
BF_DB_PORT=5432
BF_DB_NAME=bluefly
BF_DB_USER=bluefly
BF_DB_PASSWORD=your_password_here

# AI Model Configuration
BF_MODEL_PATH=/path/to/models
BF_MODEL_API_KEY=your_model_api_key_here

# Drupal Configuration
DRUPAL_ROOT=/path/to/drupal
DRUPAL_SITE=default
```

2. Set up Git configuration:
```bash
git config --global user.name "Your Name"
git config --global user.email "your.email@example.com"
```

### 5. Install Drupal (Optional)

If you're using Drupal integration:

1. Install Composer:
```bash
curl -sS https://getcomposer.org/installer | php
sudo mv composer.phar /usr/local/bin/composer
```

2. Create a new Drupal project:
```bash
composer create-project drupal/recommended-project my-drupal-site
cd my-drupal-site
```

3. Install required modules:
```bash
composer require drupal/mcp drupal/mcp_client drupal/eca
```

## Verification

After installation, verify your setup:

1. Check llmcli:
```bash
llmcli status
```

2. Verify Docker:
```bash
docker ps
docker-compose version
```

3. Test API connection:
```bash
llmcli api test
```

4. Check Drupal installation (if applicable):
```bash
llmcli drupal status
```

## Troubleshooting

Common issues and solutions:

1. **Node.js Version Mismatch**
   ```bash
   # Check current version
   node --version
   
   # Switch versions if needed
   volta install node@18
   # or
   nvm use 18
   ```

2. **Docker Permission Issues**
   ```bash
   # Add user to docker group
   sudo usermod -aG docker $USER
   
   # Log out and back in, or run:
   newgrp docker
   ```

3. **API Connection Issues**
   - Verify API key in `.env`
   - Check network connectivity
   - Ensure API service is running

4. **Drupal Installation Issues**
   - Verify Composer installation
   - Check PHP version (7.4+ required)
   - Ensure database credentials are correct

## Next Steps

- [Quick Start Guide](./quickstart): Begin using the platform
- [Configuration Guide](../reference/configuration): Advanced configuration options
- [Development Setup](../development/setup): Set up your development environment

## Support

If you encounter issues:
1. Check the [troubleshooting guide](../troubleshooting/README)
2. Search [GitLab Issues](https://gitlab.com/blueflyio/internal-projects/llm/-/issues)
3. Contact support with:
   - Installation logs
   - System information
   - Error messages
   - Steps to reproduce
